@@ -25,8 +25,8 @@ class SimpleField(Field):
 
         super().__init__(default)
 
-    def prepare_value(self, value):
-        if not isinstance(value, self.type):
+    def prepare_value(self, document, value):
+        if not isinstance(value, self.type) and value is not None:
             value = self.type(value)
 
         if self.choices is not None and value not in self.choices:
@@ -35,10 +35,10 @@ class SimpleField(Field):
         return value
 
     def to_mongo(self, document, value):
-        return self.prepare_value(value)
+        return self.prepare_value(document, value)
 
     def from_mongo(self, document, value):
-        return self.prepare_value(value)
+        return self.prepare_value(document, value)
 
 
 class ObjectIdField(SimpleField):
